@@ -1,7 +1,8 @@
+import http.client
 import logging
 import os
 from base64 import b64decode
-from typing import List, Type
+from typing import Any, List, Type
 
 import click
 
@@ -45,11 +46,29 @@ click_option_revision = click.option(
 @click.option("--org", help="Organization slug")
 @click.option("--project", help="Project slug")
 @click.option("--url", hidden=True)
+@click.option("--verbose", help="Log verbosely", is_flag=True)
 @click.version_option(version=__version__)
 @pass_memfault_cli_context
 def cli(ctx: MemfaultCliClickContext, **kwargs):
     ctx.obj.update(kwargs)
 
+    if ctx.verbose:
+        click.echo(f"version: {__version__}")
+
+        logging.basicConfig(level=logging.DEBUG)
+        requests_log = logging.getLogger("requests.packages.urllib3")
+        requests_log.setLevel(logging.DEBUG)
+        requests_log.propagate = True
+
+        httpclient_logger = logging.getLogger("http.client")
+        httpclient_logger.setLevel(logging.DEBUG)
+
+        def httpclient_log(*args) -> None:
+            httpclient_logger.log(logging.DEBUG, " ".join(args))
+
+        http.client.print = httpclient_log
+        http.client.HTTPConnection.debuglevel = 1
+
 
 def _do_upload_or_raise(ctx: MemfaultCliClickContext, path: str, uploader_cls: Type[Uploader]):
     authenticator = Authenticator.create_authenticator_given_context_or_raise(ctx)
