@@ -155,3 +155,7 @@ class MemfaultCliClickContext(object):
     @property
     def android_mapping_txt(self) -> Optional[str]:
         return self.obj.get("mapping_txt")
+
+    @property
+    def verbose(self) -> bool:
+        return self.obj.get("verbose", False)
